Name:           klee
Version:        2.2
Release:        1%{?dist}
Summary:        Symbolic Execution Engine

# Licenses
#
# * Most files are under NCSA.
# * cmake/GetGitRevisionDescription.cmake* are under Boost.
# * cmake/modules/FindSQLite3.cmake is under MIT.
# * lib/Support/RNG.cpp and runtime/klee-libc/stpcpy.c are under BSD.
# * runtime/Freestanding/memcmp.c and runtime/klee-libc/{atoi.c,memchr.c,
#   strcat.c,strncmp.c,strncpy.c,strtol.c,strtoul.c} are under BSD with
#   advertising.

License:        NCSA and Boost and MIT and BSD and BSD with advertising
URL:            https://%{name}.github.io
Source0:        https://github.com/%{name}/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz

# KLEE does not compile on 32 bit architectures.
Excludearch: %{ix86} %{arm}

# https://github.com/klee/klee/pull/1403
Patch0:         use-python3.patch
# https://github.com/klee/klee/pull/1389
Patch1:         fix-llvm12.patch
Patch2:         use-system-gtest.patch

BuildRequires:  clang
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gperftools-devel
BuildRequires:  llvm-devel
BuildRequires:  make
BuildRequires:  ninja-build
BuildRequires:  sqlite-devel
BuildRequires:  stp-devel
BuildRequires:  zlib-devel

# FIXME: Remove when rhbz#1981466 is resolved.
BuildRequires:  cryptominisat-devel
BuildRequires:  minisat2-devel

# Needed for tests.
BuildRequires:  gtest-devel
BuildRequires:  python3-lit
BuildRequires:  python3-tabulate

%description
Symbolic virtual machine built on top of the LLVM compiler infrastructure.

%prep
%autosetup -p1

%build
%cmake -GNinja                           \
       -DENABLE_DOXYGEN:BOOL=OFF         \
       -DENABLE_SOLVER_STP:BOOL=ON       \
       -DENABLE_SOLVER_Z3:BOOL=OFF       \
       -DENABLE_SOLVER_METASMT:BOOL=OFF  \
       -DENABLE_UNIT_TESTS:BOOL=ON
%cmake_build

%install
%cmake_install

%check
# Tests expect x86_64.
%ifarch x86_64
%cmake_build --target systemtests

# FIXME: Workaround as lit is currently incompatible with upstream gtest.
# https://reviews.llvm.org/D100043
for test in ./%{__cmake_builddir}/unittests/*Test; do
  ./"$test"
done
%endif

%files
%doc NEWS README.md
%license LICENSE.TXT

%{_bindir}/gen-bout
%{_bindir}/gen-random-bout
%{_bindir}/kleaver
%{_bindir}/klee
%{_bindir}/klee-replay
%{_bindir}/klee-stats
%{_bindir}/klee-zesti
%{_bindir}/ktest-tool
%{_libdir}/klee/

# Following files are meant to be used by users of KLEE and not by developers.
#
# * <klee/klee.h> contains definitions of functions used by the executed
#   bitcode to interact with KLEE itself,
# * libkleeRuntest is a support library that can be linked to the source code
#   for which the tests were generated to replay a concrete test case.
#
# For more information see https://klee.github.io/tutorials/testing-function.

%dir %{_includedir}/klee
%{_includedir}/klee/klee.h
%{_libdir}/libkleeRuntest.so
%{_libdir}/libkleeRuntest.so.1.0

%changelog
* Thu Jul 15 2021 Lukas Zaoral <lzaoral@redhat.com> - 2.2-1
- First release
